@@ -17,6 +17,23 @@ if [[ $OS_VERSION != "18.04" ]]; then
 fi
 
 #Instaling proxy settings for openvino
+
+if [[ $(echo $http_proxy) || $(echo $https_proxy) ]]; then
+        echo "installing......."
+        sudo chmod 777 /etc/environment
+        sudo echo "http_proxy=http://proxy-dmz.intel.com:911
+        https_proxy=http://proxy-dmz.intel.com:911
+        HTTP_PROXY=http://proxy-dmz.intel.com:911
+        HTTPS_PROXY=http://proxy-dmz.intel.com:91
+        ftp_proxy=http://proxy-dmz.com:911
+        NO_PROXY=localhost,127.0.0.1
+        no_proxy=localhost,127.0.0.1" > /etc/environment
+        source /etc/environment
+else
+
+        echo "proxy setting are done"
+fi
+
 #echo "Instaling proxy settings for openvino"
 
 #sudo chmod 777 /etc/environment
@@ -37,6 +54,8 @@ echo "Installing weld-porosity-detection ..."
 
 echo -e "\e[1;36m\nThis will take couple of minutes....\e[0m"
 
+sudo pip3 install onnx==1.7.0
+
 pip3 install --upgrade pip --user && pip3 install edgesoftware --user
 echo 967933fc-26ce-4efa-b674-92e32f59da87 | $HOME/.local/bin/edgesoftware install weld-porosity-detection 61717e49d8ecccee552d3ac6
 
